aboutsummaryrefslogtreecommitdiff
path: root/modules/computer.c
diff options
context:
space:
mode:
Diffstat (limited to 'modules/computer.c')
-rw-r--r--modules/computer.c5
1 files changed, 2 insertions, 3 deletions
diff --git a/modules/computer.c b/modules/computer.c
index da18b5c2..a235efc9 100644
--- a/modules/computer.c
+++ b/modules/computer.c
@@ -4,7 +4,7 @@
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, version 2.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -1083,8 +1083,7 @@ const ModuleAbout *hi_module_get_about(void)
.author = "L. A. F. Pereira",
.description = N_("Gathers high-level computer information"),
.version = VERSION,
- .license = "GNU GPL version 2",
- };
+ .license = "GNU GPL version 2 or later.",};
return &ma;
}
@@ -4,7 +4,7 @@
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, version 2.
+ * the Free Software Foundation, version 2 or later.
*
* This program is distributed in the hope that it will be useful,